# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class LineIntegrationRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        LineIntegrationRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'channel_id': 'str',
            'channel_secret': 'str',
            'switcher_secret': 'str',
            'service_code': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'channel_id': 'channelId',
            'channel_secret': 'channelSecret',
            'switcher_secret': 'switcherSecret',
            'service_code': 'serviceCode',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._channel_id = None
        self._channel_secret = None
        self._switcher_secret = None
        self._service_code = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this LineIntegrationRequest.
        The globally unique identifier for the object.

        :return: The id of this LineIntegrationRequest.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this LineIntegrationRequest.
        The globally unique identifier for the object.

        :param id: The id of this LineIntegrationRequest.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this LineIntegrationRequest.
        The name of the LINE Integration

        :return: The name of this LineIntegrationRequest.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this LineIntegrationRequest.
        The name of the LINE Integration

        :param name: The name of this LineIntegrationRequest.
        :type: str
        """
        
        self._name = name

    @property
    def channel_id(self):
        """
        Gets the channel_id of this LineIntegrationRequest.
        The Channel Id from LINE messenger. New Official LINE account: To create a new official account, LINE requires a Webhook URL. It can be created without specifying Channel Id & Channel Secret. Once the Official account is created by LINE, use the update LINE Integration API to update Channel Id and Channel Secret.  All other accounts: Channel Id is mandatory. (NOTE: ChannelId can only be updated if the integration is set to inactive)

        :return: The channel_id of this LineIntegrationRequest.
        :rtype: str
        """
        return self._channel_id

    @channel_id.setter
    def channel_id(self, channel_id):
        """
        Sets the channel_id of this LineIntegrationRequest.
        The Channel Id from LINE messenger. New Official LINE account: To create a new official account, LINE requires a Webhook URL. It can be created without specifying Channel Id & Channel Secret. Once the Official account is created by LINE, use the update LINE Integration API to update Channel Id and Channel Secret.  All other accounts: Channel Id is mandatory. (NOTE: ChannelId can only be updated if the integration is set to inactive)

        :param channel_id: The channel_id of this LineIntegrationRequest.
        :type: str
        """
        
        self._channel_id = channel_id

    @property
    def channel_secret(self):
        """
        Gets the channel_secret of this LineIntegrationRequest.
        The Channel Secret from LINE messenger. New Official LINE account: To create a new official account, LINE requires a Webhook URL. It can be created without specifying Channel Id & Channel Secret. Once the Official account is created by LINE, use the update LINE Integration API to update Channel Id and Channel Secret.  All other accounts: Channel Secret is mandatory. (NOTE: ChannelSecret can only be updated if the integration is set to inactive)

        :return: The channel_secret of this LineIntegrationRequest.
        :rtype: str
        """
        return self._channel_secret

    @channel_secret.setter
    def channel_secret(self, channel_secret):
        """
        Sets the channel_secret of this LineIntegrationRequest.
        The Channel Secret from LINE messenger. New Official LINE account: To create a new official account, LINE requires a Webhook URL. It can be created without specifying Channel Id & Channel Secret. Once the Official account is created by LINE, use the update LINE Integration API to update Channel Id and Channel Secret.  All other accounts: Channel Secret is mandatory. (NOTE: ChannelSecret can only be updated if the integration is set to inactive)

        :param channel_secret: The channel_secret of this LineIntegrationRequest.
        :type: str
        """
        
        self._channel_secret = channel_secret

    @property
    def switcher_secret(self):
        """
        Gets the switcher_secret of this LineIntegrationRequest.
        The Switcher Secret from LINE messenger. Some line official accounts are switcher functionality enabled. If the LINE account used for this integration is switcher enabled, then switcher secret is a required field. This secret can be found in your create documentation provided by LINE

        :return: The switcher_secret of this LineIntegrationRequest.
        :rtype: str
        """
        return self._switcher_secret

    @switcher_secret.setter
    def switcher_secret(self, switcher_secret):
        """
        Sets the switcher_secret of this LineIntegrationRequest.
        The Switcher Secret from LINE messenger. Some line official accounts are switcher functionality enabled. If the LINE account used for this integration is switcher enabled, then switcher secret is a required field. This secret can be found in your create documentation provided by LINE

        :param switcher_secret: The switcher_secret of this LineIntegrationRequest.
        :type: str
        """
        
        self._switcher_secret = switcher_secret

    @property
    def service_code(self):
        """
        Gets the service_code of this LineIntegrationRequest.
        The Service Code from LINE messenger. Only applicable to LINE Enterprise accounts. This service code can be found in your create documentation provided by LINE

        :return: The service_code of this LineIntegrationRequest.
        :rtype: str
        """
        return self._service_code

    @service_code.setter
    def service_code(self, service_code):
        """
        Sets the service_code of this LineIntegrationRequest.
        The Service Code from LINE messenger. Only applicable to LINE Enterprise accounts. This service code can be found in your create documentation provided by LINE

        :param service_code: The service_code of this LineIntegrationRequest.
        :type: str
        """
        
        self._service_code = service_code

    @property
    def self_uri(self):
        """
        Gets the self_uri of this LineIntegrationRequest.
        The URI for this object

        :return: The self_uri of this LineIntegrationRequest.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this LineIntegrationRequest.
        The URI for this object

        :param self_uri: The self_uri of this LineIntegrationRequest.
        :type: str
        """
        
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class CreateOutboundMessagingConversationRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CreateOutboundMessagingConversationRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'queue_id': 'str',
            'to_address': 'str',
            'to_address_messenger_type': 'str',
            'use_existing_conversation': 'bool',
            'external_contact_id': 'str',
            'external_organization_id': 'str'
        }

        self.attribute_map = {
            'queue_id': 'queueId',
            'to_address': 'toAddress',
            'to_address_messenger_type': 'toAddressMessengerType',
            'use_existing_conversation': 'useExistingConversation',
            'external_contact_id': 'externalContactId',
            'external_organization_id': 'externalOrganizationId'
        }

        self._queue_id = None
        self._to_address = None
        self._to_address_messenger_type = None
        self._use_existing_conversation = None
        self._external_contact_id = None
        self._external_organization_id = None

    @property
    def queue_id(self):
        """
        Gets the queue_id of this CreateOutboundMessagingConversationRequest.
        The ID of the queue to be associated with the message. This will determine the fromAddress of the message.

        :return: The queue_id of this CreateOutboundMessagingConversationRequest.
        :rtype: str
        """
        return self._queue_id

    @queue_id.setter
    def queue_id(self, queue_id):
        """
        Sets the queue_id of this CreateOutboundMessagingConversationRequest.
        The ID of the queue to be associated with the message. This will determine the fromAddress of the message.

        :param queue_id: The queue_id of this CreateOutboundMessagingConversationRequest.
        :type: str
        """
        
        self._queue_id = queue_id

    @property
    def to_address(self):
        """
        Gets the to_address of this CreateOutboundMessagingConversationRequest.
        The messaging address of the recipient of the message. For an SMS messenger type, the phone number address must be in E.164 format. E.g. +13175555555 or +34234234234

        :return: The to_address of this CreateOutboundMessagingConversationRequest.
        :rtype: str
        """
        return self._to_address

    @to_address.setter
    def to_address(self, to_address):
        """
        Sets the to_address of this CreateOutboundMessagingConversationRequest.
        The messaging address of the recipient of the message. For an SMS messenger type, the phone number address must be in E.164 format. E.g. +13175555555 or +34234234234

        :param to_address: The to_address of this CreateOutboundMessagingConversationRequest.
        :type: str
        """
        
        self._to_address = to_address

    @property
    def to_address_messenger_type(self):
        """
        Gets the to_address_messenger_type of this CreateOutboundMessagingConversationRequest.
        The messaging address messenger type.

        :return: The to_address_messenger_type of this CreateOutboundMessagingConversationRequest.
        :rtype: str
        """
        return self._to_address_messenger_type

    @to_address_messenger_type.setter
    def to_address_messenger_type(self, to_address_messenger_type):
        """
        Sets the to_address_messenger_type of this CreateOutboundMessagingConversationRequest.
        The messaging address messenger type.

        :param to_address_messenger_type: The to_address_messenger_type of this CreateOutboundMessagingConversationRequest.
        :type: str
        """
        allowed_values = ["sms", "facebook", "twitter", "line", "whatsapp", "webmessaging", "open"]
        if to_address_messenger_type.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for to_address_messenger_type -> " + to_address_messenger_type)
            self._to_address_messenger_type = "outdated_sdk_version"
        else:
            self._to_address_messenger_type = to_address_messenger_type

    @property
    def use_existing_conversation(self):
        """
        Gets the use_existing_conversation of this CreateOutboundMessagingConversationRequest.
        An override to use an existing conversation.  If set to true, an existing conversation will be used if there is one within the conversation window.  If set to false, create request fails if there is a conversation within the conversation window.

        :return: The use_existing_conversation of this CreateOutboundMessagingConversationRequest.
        :rtype: bool
        """
        return self._use_existing_conversation

    @use_existing_conversation.setter
    def use_existing_conversation(self, use_existing_conversation):
        """
        Sets the use_existing_conversation of this CreateOutboundMessagingConversationRequest.
        An override to use an existing conversation.  If set to true, an existing conversation will be used if there is one within the conversation window.  If set to false, create request fails if there is a conversation within the conversation window.

        :param use_existing_conversation: The use_existing_conversation of this CreateOutboundMessagingConversationRequest.
        :type: bool
        """
        
        self._use_existing_conversation = use_existing_conversation

    @property
    def external_contact_id(self):
        """
        Gets the external_contact_id of this CreateOutboundMessagingConversationRequest.
        The external contact Id of the recipient of the message.

        :return: The external_contact_id of this CreateOutboundMessagingConversationRequest.
        :rtype: str
        """
        return self._external_contact_id

    @external_contact_id.setter
    def external_contact_id(self, external_contact_id):
        """
        Sets the external_contact_id of this CreateOutboundMessagingConversationRequest.
        The external contact Id of the recipient of the message.

        :param external_contact_id: The external_contact_id of this CreateOutboundMessagingConversationRequest.
        :type: str
        """
        
        self._external_contact_id = external_contact_id

    @property
    def external_organization_id(self):
        """
        Gets the external_organization_id of this CreateOutboundMessagingConversationRequest.
        The external organization Id of the recipient of the message.

        :return: The external_organization_id of this CreateOutboundMessagingConversationRequest.
        :rtype: str
        """
        return self._external_organization_id

    @external_organization_id.setter
    def external_organization_id(self, external_organization_id):
        """
        Sets the external_organization_id of this CreateOutboundMessagingConversationRequest.
        The external organization Id of the recipient of the message.

        :param external_organization_id: The external_organization_id of this CreateOutboundMessagingConversationRequest.
        :type: str
        """
        
        self._external_organization_id = external_organization_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class Transcripts(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Transcripts - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'exact_match': 'list[str]',
            'contains': 'list[str]',
            'does_not_contain': 'list[str]'
        }

        self.attribute_map = {
            'exact_match': 'exactMatch',
            'contains': 'contains',
            'does_not_contain': 'doesNotContain'
        }

        self._exact_match = None
        self._contains = None
        self._does_not_contain = None

    @property
    def exact_match(self):
        """
        Gets the exact_match of this Transcripts.
        List of transcript contents which needs to satisfy exact match criteria

        :return: The exact_match of this Transcripts.
        :rtype: list[str]
        """
        return self._exact_match

    @exact_match.setter
    def exact_match(self, exact_match):
        """
        Sets the exact_match of this Transcripts.
        List of transcript contents which needs to satisfy exact match criteria

        :param exact_match: The exact_match of this Transcripts.
        :type: list[str]
        """
        
        self._exact_match = exact_match

    @property
    def contains(self):
        """
        Gets the contains of this Transcripts.
        List of transcript contents which needs to satisfy contains criteria

        :return: The contains of this Transcripts.
        :rtype: list[str]
        """
        return self._contains

    @contains.setter
    def contains(self, contains):
        """
        Sets the contains of this Transcripts.
        List of transcript contents which needs to satisfy contains criteria

        :param contains: The contains of this Transcripts.
        :type: list[str]
        """
        
        self._contains = contains

    @property
    def does_not_contain(self):
        """
        Gets the does_not_contain of this Transcripts.
        List of transcript contents which needs to satisfy does not contain criteria

        :return: The does_not_contain of this Transcripts.
        :rtype: list[str]
        """
        return self._does_not_contain

    @does_not_contain.setter
    def does_not_contain(self, does_not_contain):
        """
        Sets the does_not_contain of this Transcripts.
        List of transcript contents which needs to satisfy does not contain criteria

        :param does_not_contain: The does_not_contain of this Transcripts.
        :type: list[str]
        """
        
        self._does_not_contain = does_not_contain

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class WfmIntradayDataUpdateTopicIntradayHistoricalQueueData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WfmIntradayDataUpdateTopicIntradayHistoricalQueueData - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'offered': 'int',
            'completed': 'int',
            'answered': 'int',
            'abandoned': 'int',
            'average_talk_time_seconds': 'float',
            'average_after_call_work_seconds': 'float',
            'service_level_percent': 'float',
            'average_speed_of_answer_seconds': 'float'
        }

        self.attribute_map = {
            'offered': 'offered',
            'completed': 'completed',
            'answered': 'answered',
            'abandoned': 'abandoned',
            'average_talk_time_seconds': 'averageTalkTimeSeconds',
            'average_after_call_work_seconds': 'averageAfterCallWorkSeconds',
            'service_level_percent': 'serviceLevelPercent',
            'average_speed_of_answer_seconds': 'averageSpeedOfAnswerSeconds'
        }

        self._offered = None
        self._completed = None
        self._answered = None
        self._abandoned = None
        self._average_talk_time_seconds = None
        self._average_after_call_work_seconds = None
        self._service_level_percent = None
        self._average_speed_of_answer_seconds = None

    @property
    def offered(self):
        """
        Gets the offered of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :return: The offered of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :rtype: int
        """
        return self._offered

    @offered.setter
    def offered(self, offered):
        """
        Sets the offered of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :param offered: The offered of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :type: int
        """
        
        self._offered = offered

    @property
    def completed(self):
        """
        Gets the completed of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :return: The completed of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :rtype: int
        """
        return self._completed

    @completed.setter
    def completed(self, completed):
        """
        Sets the completed of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :param completed: The completed of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :type: int
        """
        
        self._completed = completed

    @property
    def answered(self):
        """
        Gets the answered of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :return: The answered of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :rtype: int
        """
        return self._answered

    @answered.setter
    def answered(self, answered):
        """
        Sets the answered of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :param answered: The answered of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :type: int
        """
        
        self._answered = answered

    @property
    def abandoned(self):
        """
        Gets the abandoned of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :return: The abandoned of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :rtype: int
        """
        return self._abandoned

    @abandoned.setter
    def abandoned(self, abandoned):
        """
        Sets the abandoned of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :param abandoned: The abandoned of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :type: int
        """
        
        self._abandoned = abandoned

    @property
    def average_talk_time_seconds(self):
        """
        Gets the average_talk_time_seconds of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :return: The average_talk_time_seconds of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :rtype: float
        """
        return self._average_talk_time_seconds

    @average_talk_time_seconds.setter
    def average_talk_time_seconds(self, average_talk_time_seconds):
        """
        Sets the average_talk_time_seconds of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :param average_talk_time_seconds: The average_talk_time_seconds of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :type: float
        """
        
        self._average_talk_time_seconds = average_talk_time_seconds

    @property
    def average_after_call_work_seconds(self):
        """
        Gets the average_after_call_work_seconds of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :return: The average_after_call_work_seconds of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :rtype: float
        """
        return self._average_after_call_work_seconds

    @average_after_call_work_seconds.setter
    def average_after_call_work_seconds(self, average_after_call_work_seconds):
        """
        Sets the average_after_call_work_seconds of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :param average_after_call_work_seconds: The average_after_call_work_seconds of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :type: float
        """
        
        self._average_after_call_work_seconds = average_after_call_work_seconds

    @property
    def service_level_percent(self):
        """
        Gets the service_level_percent of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :return: The service_level_percent of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :rtype: float
        """
        return self._service_level_percent

    @service_level_percent.setter
    def service_level_percent(self, service_level_percent):
        """
        Sets the service_level_percent of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :param service_level_percent: The service_level_percent of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :type: float
        """
        
        self._service_level_percent = service_level_percent

    @property
    def average_speed_of_answer_seconds(self):
        """
        Gets the average_speed_of_answer_seconds of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :return: The average_speed_of_answer_seconds of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :rtype: float
        """
        return self._average_speed_of_answer_seconds

    @average_speed_of_answer_seconds.setter
    def average_speed_of_answer_seconds(self, average_speed_of_answer_seconds):
        """
        Sets the average_speed_of_answer_seconds of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.


        :param average_speed_of_answer_seconds: The average_speed_of_answer_seconds of this WfmIntradayDataUpdateTopicIntradayHistoricalQueueData.
        :type: float
        """
        
        self._average_speed_of_answer_seconds = average_speed_of_answer_seconds

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class DialerAttemptLimitsConfigChangeAttemptLimits(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DialerAttemptLimitsConfigChangeAttemptLimits - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'version': 'int',
            'max_attempts_per_contact': 'int',
            'max_attempts_per_number': 'int',
            'time_zone_id': 'str',
            'reset_period': 'str',
            'recall_entries': 'dict(str, DialerAttemptLimitsConfigChangeRecallEntry)',
            'breadth_first_recalls': 'bool',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'version': 'version',
            'max_attempts_per_contact': 'maxAttemptsPerContact',
            'max_attempts_per_number': 'maxAttemptsPerNumber',
            'time_zone_id': 'timeZoneId',
            'reset_period': 'resetPeriod',
            'recall_entries': 'recallEntries',
            'breadth_first_recalls': 'breadthFirstRecalls',
            'additional_properties': 'additionalProperties'
        }

        self._id = None
        self._name = None
        self._date_created = None
        self._date_modified = None
        self._version = None
        self._max_attempts_per_contact = None
        self._max_attempts_per_number = None
        self._time_zone_id = None
        self._reset_period = None
        self._recall_entries = None
        self._breadth_first_recalls = None
        self._additional_properties = None

    @property
    def id(self):
        """
        Gets the id of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :return: The id of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :param id: The id of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :type: str
        """
        
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :return: The name of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :param name: The name of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :type: str
        """
        
        self._name = name

    @property
    def date_created(self):
        """
        Gets the date_created of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :return: The date_created of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :param date_created: The date_created of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :type: datetime
        """
        
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :return: The date_modified of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :param date_modified: The date_modified of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :type: datetime
        """
        
        self._date_modified = date_modified

    @property
    def version(self):
        """
        Gets the version of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :return: The version of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :param version: The version of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :type: int
        """
        
        self._version = version

    @property
    def max_attempts_per_contact(self):
        """
        Gets the max_attempts_per_contact of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :return: The max_attempts_per_contact of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :rtype: int
        """
        return self._max_attempts_per_contact

    @max_attempts_per_contact.setter
    def max_attempts_per_contact(self, max_attempts_per_contact):
        """
        Sets the max_attempts_per_contact of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :param max_attempts_per_contact: The max_attempts_per_contact of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :type: int
        """
        
        self._max_attempts_per_contact = max_attempts_per_contact

    @property
    def max_attempts_per_number(self):
        """
        Gets the max_attempts_per_number of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :return: The max_attempts_per_number of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :rtype: int
        """
        return self._max_attempts_per_number

    @max_attempts_per_number.setter
    def max_attempts_per_number(self, max_attempts_per_number):
        """
        Sets the max_attempts_per_number of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :param max_attempts_per_number: The max_attempts_per_number of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :type: int
        """
        
        self._max_attempts_per_number = max_attempts_per_number

    @property
    def time_zone_id(self):
        """
        Gets the time_zone_id of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :return: The time_zone_id of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :rtype: str
        """
        return self._time_zone_id

    @time_zone_id.setter
    def time_zone_id(self, time_zone_id):
        """
        Sets the time_zone_id of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :param time_zone_id: The time_zone_id of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :type: str
        """
        
        self._time_zone_id = time_zone_id

    @property
    def reset_period(self):
        """
        Gets the reset_period of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :return: The reset_period of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :rtype: str
        """
        return self._reset_period

    @reset_period.setter
    def reset_period(self, reset_period):
        """
        Sets the reset_period of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :param reset_period: The reset_period of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :type: str
        """
        allowed_values = ["NEVER", "TODAY"]
        if reset_period.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for reset_period -> " + reset_period)
            self._reset_period = "outdated_sdk_version"
        else:
            self._reset_period = reset_period

    @property
    def recall_entries(self):
        """
        Gets the recall_entries of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :return: The recall_entries of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :rtype: dict(str, DialerAttemptLimitsConfigChangeRecallEntry)
        """
        return self._recall_entries

    @recall_entries.setter
    def recall_entries(self, recall_entries):
        """
        Sets the recall_entries of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :param recall_entries: The recall_entries of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :type: dict(str, DialerAttemptLimitsConfigChangeRecallEntry)
        """
        
        self._recall_entries = recall_entries

    @property
    def breadth_first_recalls(self):
        """
        Gets the breadth_first_recalls of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :return: The breadth_first_recalls of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :rtype: bool
        """
        return self._breadth_first_recalls

    @breadth_first_recalls.setter
    def breadth_first_recalls(self, breadth_first_recalls):
        """
        Sets the breadth_first_recalls of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :param breadth_first_recalls: The breadth_first_recalls of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :type: bool
        """
        
        self._breadth_first_recalls = breadth_first_recalls

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :return: The additional_properties of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this DialerAttemptLimitsConfigChangeAttemptLimits.


        :param additional_properties: The additional_properties of this DialerAttemptLimitsConfigChangeAttemptLimits.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class QueueConversationEventTopicErrorDetails(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QueueConversationEventTopicErrorDetails - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'status': 'int',
            'code': 'str',
            'message': 'str',
            'message_with_params': 'str',
            'message_params': 'dict(str, str)',
            'context_id': 'str',
            'uri': 'str',
            'additional_properties': 'object'
        }

        self.attribute_map = {
            'status': 'status',
            'code': 'code',
            'message': 'message',
            'message_with_params': 'messageWithParams',
            'message_params': 'messageParams',
            'context_id': 'contextId',
            'uri': 'uri',
            'additional_properties': 'additionalProperties'
        }

        self._status = None
        self._code = None
        self._message = None
        self._message_with_params = None
        self._message_params = None
        self._context_id = None
        self._uri = None
        self._additional_properties = None

    @property
    def status(self):
        """
        Gets the status of this QueueConversationEventTopicErrorDetails.


        :return: The status of this QueueConversationEventTopicErrorDetails.
        :rtype: int
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this QueueConversationEventTopicErrorDetails.


        :param status: The status of this QueueConversationEventTopicErrorDetails.
        :type: int
        """
        
        self._status = status

    @property
    def code(self):
        """
        Gets the code of this QueueConversationEventTopicErrorDetails.


        :return: The code of this QueueConversationEventTopicErrorDetails.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this QueueConversationEventTopicErrorDetails.


        :param code: The code of this QueueConversationEventTopicErrorDetails.
        :type: str
        """
        
        self._code = code

    @property
    def message(self):
        """
        Gets the message of this QueueConversationEventTopicErrorDetails.


        :return: The message of this QueueConversationEventTopicErrorDetails.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this QueueConversationEventTopicErrorDetails.


        :param message: The message of this QueueConversationEventTopicErrorDetails.
        :type: str
        """
        
        self._message = message

    @property
    def message_with_params(self):
        """
        Gets the message_with_params of this QueueConversationEventTopicErrorDetails.


        :return: The message_with_params of this QueueConversationEventTopicErrorDetails.
        :rtype: str
        """
        return self._message_with_params

    @message_with_params.setter
    def message_with_params(self, message_with_params):
        """
        Sets the message_with_params of this QueueConversationEventTopicErrorDetails.


        :param message_with_params: The message_with_params of this QueueConversationEventTopicErrorDetails.
        :type: str
        """
        
        self._message_with_params = message_with_params

    @property
    def message_params(self):
        """
        Gets the message_params of this QueueConversationEventTopicErrorDetails.


        :return: The message_params of this QueueConversationEventTopicErrorDetails.
        :rtype: dict(str, str)
        """
        return self._message_params

    @message_params.setter
    def message_params(self, message_params):
        """
        Sets the message_params of this QueueConversationEventTopicErrorDetails.


        :param message_params: The message_params of this QueueConversationEventTopicErrorDetails.
        :type: dict(str, str)
        """
        
        self._message_params = message_params

    @property
    def context_id(self):
        """
        Gets the context_id of this QueueConversationEventTopicErrorDetails.


        :return: The context_id of this QueueConversationEventTopicErrorDetails.
        :rtype: str
        """
        return self._context_id

    @context_id.setter
    def context_id(self, context_id):
        """
        Sets the context_id of this QueueConversationEventTopicErrorDetails.


        :param context_id: The context_id of this QueueConversationEventTopicErrorDetails.
        :type: str
        """
        
        self._context_id = context_id

    @property
    def uri(self):
        """
        Gets the uri of this QueueConversationEventTopicErrorDetails.


        :return: The uri of this QueueConversationEventTopicErrorDetails.
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """
        Sets the uri of this QueueConversationEventTopicErrorDetails.


        :param uri: The uri of this QueueConversationEventTopicErrorDetails.
        :type: str
        """
        
        self._uri = uri

    @property
    def additional_properties(self):
        """
        Gets the additional_properties of this QueueConversationEventTopicErrorDetails.


        :return: The additional_properties of this QueueConversationEventTopicErrorDetails.
        :rtype: object
        """
        return self._additional_properties

    @additional_properties.setter
    def additional_properties(self, additional_properties):
        """
        Sets the additional_properties of this QueueConversationEventTopicErrorDetails.


        :param additional_properties: The additional_properties of this QueueConversationEventTopicErrorDetails.
        :type: object
        """
        
        self._additional_properties = additional_properties

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class UserScheduleShift(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserScheduleShift - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'week_schedule': 'WeekScheduleReference',
            'id': 'str',
            'start_date': 'datetime',
            'length_in_minutes': 'int',
            'activities': 'list[UserScheduleActivity]',
            'delete': 'bool',
            'manually_edited': 'bool'
        }

        self.attribute_map = {
            'week_schedule': 'weekSchedule',
            'id': 'id',
            'start_date': 'startDate',
            'length_in_minutes': 'lengthInMinutes',
            'activities': 'activities',
            'delete': 'delete',
            'manually_edited': 'manuallyEdited'
        }

        self._week_schedule = None
        self._id = None
        self._start_date = None
        self._length_in_minutes = None
        self._activities = None
        self._delete = None
        self._manually_edited = None

    @property
    def week_schedule(self):
        """
        Gets the week_schedule of this UserScheduleShift.
        The schedule to which this shift belongs

        :return: The week_schedule of this UserScheduleShift.
        :rtype: WeekScheduleReference
        """
        return self._week_schedule

    @week_schedule.setter
    def week_schedule(self, week_schedule):
        """
        Sets the week_schedule of this UserScheduleShift.
        The schedule to which this shift belongs

        :param week_schedule: The week_schedule of this UserScheduleShift.
        :type: WeekScheduleReference
        """
        
        self._week_schedule = week_schedule

    @property
    def id(self):
        """
        Gets the id of this UserScheduleShift.
        ID of the schedule shift. This is only for the case of updating and deleting an existing shift

        :return: The id of this UserScheduleShift.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this UserScheduleShift.
        ID of the schedule shift. This is only for the case of updating and deleting an existing shift

        :param id: The id of this UserScheduleShift.
        :type: str
        """
        
        self._id = id

    @property
    def start_date(self):
        """
        Gets the start_date of this UserScheduleShift.
        Start time in UTC for this shift. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :return: The start_date of this UserScheduleShift.
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """
        Sets the start_date of this UserScheduleShift.
        Start time in UTC for this shift. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss[.mmm]Z

        :param start_date: The start_date of this UserScheduleShift.
        :type: datetime
        """
        
        self._start_date = start_date

    @property
    def length_in_minutes(self):
        """
        Gets the length_in_minutes of this UserScheduleShift.
        Length of this shift in minutes

        :return: The length_in_minutes of this UserScheduleShift.
        :rtype: int
        """
        return self._length_in_minutes

    @length_in_minutes.setter
    def length_in_minutes(self, length_in_minutes):
        """
        Sets the length_in_minutes of this UserScheduleShift.
        Length of this shift in minutes

        :param length_in_minutes: The length_in_minutes of this UserScheduleShift.
        :type: int
        """
        
        self._length_in_minutes = length_in_minutes

    @property
    def activities(self):
        """
        Gets the activities of this UserScheduleShift.
        List of activities in this shift

        :return: The activities of this UserScheduleShift.
        :rtype: list[UserScheduleActivity]
        """
        return self._activities

    @activities.setter
    def activities(self, activities):
        """
        Sets the activities of this UserScheduleShift.
        List of activities in this shift

        :param activities: The activities of this UserScheduleShift.
        :type: list[UserScheduleActivity]
        """
        
        self._activities = activities

    @property
    def delete(self):
        """
        Gets the delete of this UserScheduleShift.
        If marked true for updating this schedule shift, it will be deleted

        :return: The delete of this UserScheduleShift.
        :rtype: bool
        """
        return self._delete

    @delete.setter
    def delete(self, delete):
        """
        Sets the delete of this UserScheduleShift.
        If marked true for updating this schedule shift, it will be deleted

        :param delete: The delete of this UserScheduleShift.
        :type: bool
        """
        
        self._delete = delete

    @property
    def manually_edited(self):
        """
        Gets the manually_edited of this UserScheduleShift.
        Whether the shift was set as manually edited

        :return: The manually_edited of this UserScheduleShift.
        :rtype: bool
        """
        return self._manually_edited

    @manually_edited.setter
    def manually_edited(self, manually_edited):
        """
        Sets the manually_edited of this UserScheduleShift.
        Whether the shift was set as manually edited

        :param manually_edited: The manually_edited of this UserScheduleShift.
        :type: bool
        """
        
        self._manually_edited = manually_edited

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class UserExpands(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        UserExpands - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'routing_status': 'RoutingStatus',
            'presence': 'UserPresence',
            'conversation_summary': 'UserConversationSummary',
            'out_of_office': 'OutOfOffice',
            'geolocation': 'Geolocation',
            'station': 'UserStations',
            'authorization': 'UserAuthorization'
        }

        self.attribute_map = {
            'routing_status': 'routingStatus',
            'presence': 'presence',
            'conversation_summary': 'conversationSummary',
            'out_of_office': 'outOfOffice',
            'geolocation': 'geolocation',
            'station': 'station',
            'authorization': 'authorization'
        }

        self._routing_status = None
        self._presence = None
        self._conversation_summary = None
        self._out_of_office = None
        self._geolocation = None
        self._station = None
        self._authorization = None

    @property
    def routing_status(self):
        """
        Gets the routing_status of this UserExpands.
        ACD routing status

        :return: The routing_status of this UserExpands.
        :rtype: RoutingStatus
        """
        return self._routing_status

    @routing_status.setter
    def routing_status(self, routing_status):
        """
        Sets the routing_status of this UserExpands.
        ACD routing status

        :param routing_status: The routing_status of this UserExpands.
        :type: RoutingStatus
        """
        
        self._routing_status = routing_status

    @property
    def presence(self):
        """
        Gets the presence of this UserExpands.
        Active presence

        :return: The presence of this UserExpands.
        :rtype: UserPresence
        """
        return self._presence

    @presence.setter
    def presence(self, presence):
        """
        Sets the presence of this UserExpands.
        Active presence

        :param presence: The presence of this UserExpands.
        :type: UserPresence
        """
        
        self._presence = presence

    @property
    def conversation_summary(self):
        """
        Gets the conversation_summary of this UserExpands.
        Summary of conversion statistics for conversation types.

        :return: The conversation_summary of this UserExpands.
        :rtype: UserConversationSummary
        """
        return self._conversation_summary

    @conversation_summary.setter
    def conversation_summary(self, conversation_summary):
        """
        Sets the conversation_summary of this UserExpands.
        Summary of conversion statistics for conversation types.

        :param conversation_summary: The conversation_summary of this UserExpands.
        :type: UserConversationSummary
        """
        
        self._conversation_summary = conversation_summary

    @property
    def out_of_office(self):
        """
        Gets the out_of_office of this UserExpands.
        Determine if out of office is enabled

        :return: The out_of_office of this UserExpands.
        :rtype: OutOfOffice
        """
        return self._out_of_office

    @out_of_office.setter
    def out_of_office(self, out_of_office):
        """
        Sets the out_of_office of this UserExpands.
        Determine if out of office is enabled

        :param out_of_office: The out_of_office of this UserExpands.
        :type: OutOfOffice
        """
        
        self._out_of_office = out_of_office

    @property
    def geolocation(self):
        """
        Gets the geolocation of this UserExpands.
        Current geolocation position

        :return: The geolocation of this UserExpands.
        :rtype: Geolocation
        """
        return self._geolocation

    @geolocation.setter
    def geolocation(self, geolocation):
        """
        Sets the geolocation of this UserExpands.
        Current geolocation position

        :param geolocation: The geolocation of this UserExpands.
        :type: Geolocation
        """
        
        self._geolocation = geolocation

    @property
    def station(self):
        """
        Gets the station of this UserExpands.
        Effective, default, and last station information

        :return: The station of this UserExpands.
        :rtype: UserStations
        """
        return self._station

    @station.setter
    def station(self, station):
        """
        Sets the station of this UserExpands.
        Effective, default, and last station information

        :param station: The station of this UserExpands.
        :type: UserStations
        """
        
        self._station = station

    @property
    def authorization(self):
        """
        Gets the authorization of this UserExpands.
        Roles and permissions assigned to the user

        :return: The authorization of this UserExpands.
        :rtype: UserAuthorization
        """
        return self._authorization

    @authorization.setter
    def authorization(self, authorization):
        """
        Sets the authorization of this UserExpands.
        Roles and permissions assigned to the user

        :param authorization: The authorization of this UserExpands.
        :type: UserAuthorization
        """
        
        self._authorization = authorization

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class AnalyticsParticipantWithoutAttributes(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        AnalyticsParticipantWithoutAttributes - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'participant_id': 'str',
            'participant_name': 'str',
            'user_id': 'str',
            'purpose': 'str',
            'external_contact_id': 'str',
            'external_organization_id': 'str',
            'flagged_reason': 'str',
            'team_id': 'str',
            'sessions': 'list[AnalyticsSession]'
        }

        self.attribute_map = {
            'participant_id': 'participantId',
            'participant_name': 'participantName',
            'user_id': 'userId',
            'purpose': 'purpose',
            'external_contact_id': 'externalContactId',
            'external_organization_id': 'externalOrganizationId',
            'flagged_reason': 'flaggedReason',
            'team_id': 'teamId',
            'sessions': 'sessions'
        }

        self._participant_id = None
        self._participant_name = None
        self._user_id = None
        self._purpose = None
        self._external_contact_id = None
        self._external_organization_id = None
        self._flagged_reason = None
        self._team_id = None
        self._sessions = None

    @property
    def participant_id(self):
        """
        Gets the participant_id of this AnalyticsParticipantWithoutAttributes.
        Unique identifier for the participant

        :return: The participant_id of this AnalyticsParticipantWithoutAttributes.
        :rtype: str
        """
        return self._participant_id

    @participant_id.setter
    def participant_id(self, participant_id):
        """
        Sets the participant_id of this AnalyticsParticipantWithoutAttributes.
        Unique identifier for the participant

        :param participant_id: The participant_id of this AnalyticsParticipantWithoutAttributes.
        :type: str
        """
        
        self._participant_id = participant_id

    @property
    def participant_name(self):
        """
        Gets the participant_name of this AnalyticsParticipantWithoutAttributes.
        A human readable name identifying the participant

        :return: The participant_name of this AnalyticsParticipantWithoutAttributes.
        :rtype: str
        """
        return self._participant_name

    @participant_name.setter
    def participant_name(self, participant_name):
        """
        Sets the participant_name of this AnalyticsParticipantWithoutAttributes.
        A human readable name identifying the participant

        :param participant_name: The participant_name of this AnalyticsParticipantWithoutAttributes.
        :type: str
        """
        
        self._participant_name = participant_name

    @property
    def user_id(self):
        """
        Gets the user_id of this AnalyticsParticipantWithoutAttributes.
        If a user, then this will be the unique identifier for the user

        :return: The user_id of this AnalyticsParticipantWithoutAttributes.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this AnalyticsParticipantWithoutAttributes.
        If a user, then this will be the unique identifier for the user

        :param user_id: The user_id of this AnalyticsParticipantWithoutAttributes.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def purpose(self):
        """
        Gets the purpose of this AnalyticsParticipantWithoutAttributes.
        The participant's purpose

        :return: The purpose of this AnalyticsParticipantWithoutAttributes.
        :rtype: str
        """
        return self._purpose

    @purpose.setter
    def purpose(self, purpose):
        """
        Sets the purpose of this AnalyticsParticipantWithoutAttributes.
        The participant's purpose

        :param purpose: The purpose of this AnalyticsParticipantWithoutAttributes.
        :type: str
        """
        allowed_values = ["manual", "dialer", "inbound", "acd", "ivr", "voicemail", "outbound", "agent", "user", "station", "group", "customer", "external", "fax", "workflow", "campaign", "api"]
        if purpose.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for purpose -> " + purpose)
            self._purpose = "outdated_sdk_version"
        else:
            self._purpose = purpose

    @property
    def external_contact_id(self):
        """
        Gets the external_contact_id of this AnalyticsParticipantWithoutAttributes.
        External Contact Identifier

        :return: The external_contact_id of this AnalyticsParticipantWithoutAttributes.
        :rtype: str
        """
        return self._external_contact_id

    @external_contact_id.setter
    def external_contact_id(self, external_contact_id):
        """
        Sets the external_contact_id of this AnalyticsParticipantWithoutAttributes.
        External Contact Identifier

        :param external_contact_id: The external_contact_id of this AnalyticsParticipantWithoutAttributes.
        :type: str
        """
        
        self._external_contact_id = external_contact_id

    @property
    def external_organization_id(self):
        """
        Gets the external_organization_id of this AnalyticsParticipantWithoutAttributes.
        External Organization Identifier

        :return: The external_organization_id of this AnalyticsParticipantWithoutAttributes.
        :rtype: str
        """
        return self._external_organization_id

    @external_organization_id.setter
    def external_organization_id(self, external_organization_id):
        """
        Sets the external_organization_id of this AnalyticsParticipantWithoutAttributes.
        External Organization Identifier

        :param external_organization_id: The external_organization_id of this AnalyticsParticipantWithoutAttributes.
        :type: str
        """
        
        self._external_organization_id = external_organization_id

    @property
    def flagged_reason(self):
        """
        Gets the flagged_reason of this AnalyticsParticipantWithoutAttributes.
        Reason for which participant flagged conversation

        :return: The flagged_reason of this AnalyticsParticipantWithoutAttributes.
        :rtype: str
        """
        return self._flagged_reason

    @flagged_reason.setter
    def flagged_reason(self, flagged_reason):
        """
        Sets the flagged_reason of this AnalyticsParticipantWithoutAttributes.
        Reason for which participant flagged conversation

        :param flagged_reason: The flagged_reason of this AnalyticsParticipantWithoutAttributes.
        :type: str
        """
        allowed_values = ["general"]
        if flagged_reason.lower() not in map(str.lower, allowed_values):
            # print("Invalid value for flagged_reason -> " + flagged_reason)
            self._flagged_reason = "outdated_sdk_version"
        else:
            self._flagged_reason = flagged_reason

    @property
    def team_id(self):
        """
        Gets the team_id of this AnalyticsParticipantWithoutAttributes.
        The team id the user is a member of

        :return: The team_id of this AnalyticsParticipantWithoutAttributes.
        :rtype: str
        """
        return self._team_id

    @team_id.setter
    def team_id(self, team_id):
        """
        Sets the team_id of this AnalyticsParticipantWithoutAttributes.
        The team id the user is a member of

        :param team_id: The team_id of this AnalyticsParticipantWithoutAttributes.
        :type: str
        """
        
        self._team_id = team_id

    @property
    def sessions(self):
        """
        Gets the sessions of this AnalyticsParticipantWithoutAttributes.
        List of sessions associated to this participant

        :return: The sessions of this AnalyticsParticipantWithoutAttributes.
        :rtype: list[AnalyticsSession]
        """
        return self._sessions

    @sessions.setter
    def sessions(self, sessions):
        """
        Sets the sessions of this AnalyticsParticipantWithoutAttributes.
        List of sessions associated to this participant

        :param sessions: The sessions of this AnalyticsParticipantWithoutAttributes.
        :type: list[AnalyticsSession]
        """
        
        self._sessions = sessions

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class SurveyScoringSet(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SurveyScoringSet - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'total_score': 'float',
            'nps_score': 'int',
            'question_group_scores': 'list[SurveyQuestionGroupScore]'
        }

        self.attribute_map = {
            'total_score': 'totalScore',
            'nps_score': 'npsScore',
            'question_group_scores': 'questionGroupScores'
        }

        self._total_score = None
        self._nps_score = None
        self._question_group_scores = None

    @property
    def total_score(self):
        """
        Gets the total_score of this SurveyScoringSet.


        :return: The total_score of this SurveyScoringSet.
        :rtype: float
        """
        return self._total_score

    @total_score.setter
    def total_score(self, total_score):
        """
        Sets the total_score of this SurveyScoringSet.


        :param total_score: The total_score of this SurveyScoringSet.
        :type: float
        """
        
        self._total_score = total_score

    @property
    def nps_score(self):
        """
        Gets the nps_score of this SurveyScoringSet.


        :return: The nps_score of this SurveyScoringSet.
        :rtype: int
        """
        return self._nps_score

    @nps_score.setter
    def nps_score(self, nps_score):
        """
        Sets the nps_score of this SurveyScoringSet.


        :param nps_score: The nps_score of this SurveyScoringSet.
        :type: int
        """
        
        self._nps_score = nps_score

    @property
    def question_group_scores(self):
        """
        Gets the question_group_scores of this SurveyScoringSet.


        :return: The question_group_scores of this SurveyScoringSet.
        :rtype: list[SurveyQuestionGroupScore]
        """
        return self._question_group_scores

    @question_group_scores.setter
    def question_group_scores(self, question_group_scores):
        """
        Sets the question_group_scores of this SurveyScoringSet.


        :param question_group_scores: The question_group_scores of this SurveyScoringSet.
        :type: list[SurveyQuestionGroupScore]
        """
        
        self._question_group_scores = question_group_scores

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems
import re
import json

from ..utils import sanitize_for_serialization

class GDPRSubject(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        GDPRSubject - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'name': 'str',
            'user_id': 'str',
            'external_contact_id': 'str',
            'dialer_contact_id': 'DialerContactId',
            'journey_customer': 'GDPRJourneyCustomer',
            'social_handle': 'SocialHandle',
            'addresses': 'list[str]',
            'phone_numbers': 'list[str]',
            'email_addresses': 'list[str]'
        }

        self.attribute_map = {
            'name': 'name',
            'user_id': 'userId',
            'external_contact_id': 'externalContactId',
            'dialer_contact_id': 'dialerContactId',
            'journey_customer': 'journeyCustomer',
            'social_handle': 'socialHandle',
            'addresses': 'addresses',
            'phone_numbers': 'phoneNumbers',
            'email_addresses': 'emailAddresses'
        }

        self._name = None
        self._user_id = None
        self._external_contact_id = None
        self._dialer_contact_id = None
        self._journey_customer = None
        self._social_handle = None
        self._addresses = None
        self._phone_numbers = None
        self._email_addresses = None

    @property
    def name(self):
        """
        Gets the name of this GDPRSubject.


        :return: The name of this GDPRSubject.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this GDPRSubject.


        :param name: The name of this GDPRSubject.
        :type: str
        """
        
        self._name = name

    @property
    def user_id(self):
        """
        Gets the user_id of this GDPRSubject.


        :return: The user_id of this GDPRSubject.
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """
        Sets the user_id of this GDPRSubject.


        :param user_id: The user_id of this GDPRSubject.
        :type: str
        """
        
        self._user_id = user_id

    @property
    def external_contact_id(self):
        """
        Gets the external_contact_id of this GDPRSubject.


        :return: The external_contact_id of this GDPRSubject.
        :rtype: str
        """
        return self._external_contact_id

    @external_contact_id.setter
    def external_contact_id(self, external_contact_id):
        """
        Sets the external_contact_id of this GDPRSubject.


        :param external_contact_id: The external_contact_id of this GDPRSubject.
        :type: str
        """
        
        self._external_contact_id = external_contact_id

    @property
    def dialer_contact_id(self):
        """
        Gets the dialer_contact_id of this GDPRSubject.


        :return: The dialer_contact_id of this GDPRSubject.
        :rtype: DialerContactId
        """
        return self._dialer_contact_id

    @dialer_contact_id.setter
    def dialer_contact_id(self, dialer_contact_id):
        """
        Sets the dialer_contact_id of this GDPRSubject.


        :param dialer_contact_id: The dialer_contact_id of this GDPRSubject.
        :type: DialerContactId
        """
        
        self._dialer_contact_id = dialer_contact_id

    @property
    def journey_customer(self):
        """
        Gets the journey_customer of this GDPRSubject.


        :return: The journey_customer of this GDPRSubject.
        :rtype: GDPRJourneyCustomer
        """
        return self._journey_customer

    @journey_customer.setter
    def journey_customer(self, journey_customer):
        """
        Sets the journey_customer of this GDPRSubject.


        :param journey_customer: The journey_customer of this GDPRSubject.
        :type: GDPRJourneyCustomer
        """
        
        self._journey_customer = journey_customer

    @property
    def social_handle(self):
        """
        Gets the social_handle of this GDPRSubject.


        :return: The social_handle of this GDPRSubject.
        :rtype: SocialHandle
        """
        return self._social_handle

    @social_handle.setter
    def social_handle(self, social_handle):
        """
        Sets the social_handle of this GDPRSubject.


        :param social_handle: The social_handle of this GDPRSubject.
        :type: SocialHandle
        """
        
        self._social_handle = social_handle

    @property
    def addresses(self):
        """
        Gets the addresses of this GDPRSubject.


        :return: The addresses of this GDPRSubject.
        :rtype: list[str]
        """
        return self._addresses

    @addresses.setter
    def addresses(self, addresses):
        """
        Sets the addresses of this GDPRSubject.


        :param addresses: The addresses of this GDPRSubject.
        :type: list[str]
        """
        
        self._addresses = addresses

    @property
    def phone_numbers(self):
        """
        Gets the phone_numbers of this GDPRSubject.


        :return: The phone_numbers of this GDPRSubject.
        :rtype: list[str]
        """
        return self._phone_numbers

    @phone_numbers.setter
    def phone_numbers(self, phone_numbers):
        """
        Sets the phone_numbers of this GDPRSubject.


        :param phone_numbers: The phone_numbers of this GDPRSubject.
        :type: list[str]
        """
        
        self._phone_numbers = phone_numbers

    @property
    def email_addresses(self):
        """
        Gets the email_addresses of this GDPRSubject.


        :return: The email_addresses of this GDPRSubject.
        :rtype: list[str]
        """
        return self._email_addresses

    @email_addresses.setter
    def email_addresses(self, email_addresses):
        """
        Sets the email_addresses of this GDPRSubject.


        :param email_addresses: The email_addresses of this GDPRSubject.
        :type: list[str]
        """
        
        self._email_addresses = email_addresses

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_json(self):
        """
        Returns the model as raw JSON
        """
        return json.dumps(sanitize_for_serialization(self.to_dict()))

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

